# coding: utf-8

# flake8: noqa

"""
    IdentityNow Beta API

    Use these APIs to interact with the IdentityNow platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.1"

# import apis into sdk package
from sailpoint.beta.api.access_profiles_api import AccessProfilesApi
from sailpoint.beta.api.access_request_approvals_api import AccessRequestApprovalsApi
from sailpoint.beta.api.access_request_identity_metrics_api import AccessRequestIdentityMetricsApi
from sailpoint.beta.api.access_requests_api import AccessRequestsApi
from sailpoint.beta.api.account_activities_api import AccountActivitiesApi
from sailpoint.beta.api.account_aggregations_api import AccountAggregationsApi
from sailpoint.beta.api.account_usages_api import AccountUsagesApi
from sailpoint.beta.api.accounts_api import AccountsApi
from sailpoint.beta.api.auth_profile_api import AuthProfileApi
from sailpoint.beta.api.certification_campaigns_api import CertificationCampaignsApi
from sailpoint.beta.api.certifications_api import CertificationsApi
from sailpoint.beta.api.connector_rule_management_api import ConnectorRuleManagementApi
from sailpoint.beta.api.connectors_api import ConnectorsApi
from sailpoint.beta.api.custom_forms_api import CustomFormsApi
from sailpoint.beta.api.custom_password_instructions_api import CustomPasswordInstructionsApi
from sailpoint.beta.api.entitlements_api import EntitlementsApi
from sailpoint.beta.api.governance_groups_api import GovernanceGroupsApi
from sailpoint.beta.api.iai_access_request_recommendations_api import IAIAccessRequestRecommendationsApi
from sailpoint.beta.api.iai_common_access_api import IAICommonAccessApi
from sailpoint.beta.api.iai_message_catalogs_api import IAIMessageCatalogsApi
from sailpoint.beta.api.iai_outliers_api import IAIOutliersApi
from sailpoint.beta.api.iai_peer_group_strategies_api import IAIPeerGroupStrategiesApi
from sailpoint.beta.api.iai_recommendations_api import IAIRecommendationsApi
from sailpoint.beta.api.iai_role_mining_api import IAIRoleMiningApi
from sailpoint.beta.api.identities_api import IdentitiesApi
from sailpoint.beta.api.identity_attributes_api import IdentityAttributesApi
from sailpoint.beta.api.identity_history_api import IdentityHistoryApi
from sailpoint.beta.api.identity_profiles_api import IdentityProfilesApi
from sailpoint.beta.api.lifecycle_states_api import LifecycleStatesApi
from sailpoint.beta.api.mfa_configuration_api import MFAConfigurationApi
from sailpoint.beta.api.mfa_controller_api import MFAControllerApi
from sailpoint.beta.api.managed_clients_api import ManagedClientsApi
from sailpoint.beta.api.managed_clusters_api import ManagedClustersApi
from sailpoint.beta.api.non_employee_lifecycle_management_api import NonEmployeeLifecycleManagementApi
from sailpoint.beta.api.notifications_api import NotificationsApi
from sailpoint.beta.api.o_auth_clients_api import OAuthClientsApi
from sailpoint.beta.api.org_config_api import OrgConfigApi
from sailpoint.beta.api.password_configuration_api import PasswordConfigurationApi
from sailpoint.beta.api.password_dictionary_api import PasswordDictionaryApi
from sailpoint.beta.api.password_management_api import PasswordManagementApi
from sailpoint.beta.api.password_sync_groups_api import PasswordSyncGroupsApi
from sailpoint.beta.api.personal_access_tokens_api import PersonalAccessTokensApi
from sailpoint.beta.api.public_identities_config_api import PublicIdentitiesConfigApi
from sailpoint.beta.api.requestable_objects_api import RequestableObjectsApi
from sailpoint.beta.api.role_insights_api import RoleInsightsApi
from sailpoint.beta.api.roles_api import RolesApi
from sailpoint.beta.api.sod_policy_api import SODPolicyApi
from sailpoint.beta.api.sod_violations_api import SODViolationsApi
from sailpoint.beta.api.sp_config_api import SPConfigApi
from sailpoint.beta.api.search_attribute_configuration_api import SearchAttributeConfigurationApi
from sailpoint.beta.api.segments_api import SegmentsApi
from sailpoint.beta.api.service_desk_integration_api import ServiceDeskIntegrationApi
from sailpoint.beta.api.source_usages_api import SourceUsagesApi
from sailpoint.beta.api.sources_api import SourcesApi
from sailpoint.beta.api.tagged_objects_api import TaggedObjectsApi
from sailpoint.beta.api.task_management_api import TaskManagementApi
from sailpoint.beta.api.tenant_api import TenantApi
from sailpoint.beta.api.transforms_api import TransformsApi
from sailpoint.beta.api.triggers_api import TriggersApi
from sailpoint.beta.api.work_items_api import WorkItemsApi
from sailpoint.beta.api.work_reassignment_api import WorkReassignmentApi
from sailpoint.beta.api.workflows_api import WorkflowsApi

# import ApiClient
from sailpoint.beta.api_response import ApiResponse
from sailpoint.beta.api_client import ApiClient
from sailpoint.beta.configuration import Configuration
from sailpoint.beta.exceptions import OpenApiException
from sailpoint.beta.exceptions import ApiTypeError
from sailpoint.beta.exceptions import ApiValueError
from sailpoint.beta.exceptions import ApiKeyError
from sailpoint.beta.exceptions import ApiAttributeError
from sailpoint.beta.exceptions import ApiException

# import models into sdk package
from sailpoint.beta.models.access_constraint import AccessConstraint
from sailpoint.beta.models.access_criteria import AccessCriteria
from sailpoint.beta.models.access_criteria_criteria_list_inner import AccessCriteriaCriteriaListInner
from sailpoint.beta.models.access_item_access_profile_response import AccessItemAccessProfileResponse
from sailpoint.beta.models.access_item_account_response import AccessItemAccountResponse
from sailpoint.beta.models.access_item_app_response import AccessItemAppResponse
from sailpoint.beta.models.access_item_approver_dto import AccessItemApproverDto
from sailpoint.beta.models.access_item_associated import AccessItemAssociated
from sailpoint.beta.models.access_item_associated_access_item import AccessItemAssociatedAccessItem
from sailpoint.beta.models.access_item_diff import AccessItemDiff
from sailpoint.beta.models.access_item_entitlement_response import AccessItemEntitlementResponse
from sailpoint.beta.models.access_item_owner_dto import AccessItemOwnerDto
from sailpoint.beta.models.access_item_ref import AccessItemRef
from sailpoint.beta.models.access_item_removed import AccessItemRemoved
from sailpoint.beta.models.access_item_requested_for import AccessItemRequestedFor
from sailpoint.beta.models.access_item_requested_for_dto import AccessItemRequestedForDto
from sailpoint.beta.models.access_item_requester import AccessItemRequester
from sailpoint.beta.models.access_item_requester_dto import AccessItemRequesterDto
from sailpoint.beta.models.access_item_reviewed_by import AccessItemReviewedBy
from sailpoint.beta.models.access_item_role_response import AccessItemRoleResponse
from sailpoint.beta.models.access_profile import AccessProfile
from sailpoint.beta.models.access_profile_approval_scheme import AccessProfileApprovalScheme
from sailpoint.beta.models.access_profile_bulk_delete_request import AccessProfileBulkDeleteRequest
from sailpoint.beta.models.access_profile_bulk_delete_response import AccessProfileBulkDeleteResponse
from sailpoint.beta.models.access_profile_bulk_update_request_inner import AccessProfileBulkUpdateRequestInner
from sailpoint.beta.models.access_profile_ref import AccessProfileRef
from sailpoint.beta.models.access_profile_source_ref import AccessProfileSourceRef
from sailpoint.beta.models.access_profile_update_item import AccessProfileUpdateItem
from sailpoint.beta.models.access_profile_usage import AccessProfileUsage
from sailpoint.beta.models.access_profile_usage_used_by_inner import AccessProfileUsageUsedByInner
from sailpoint.beta.models.access_recommendation_message import AccessRecommendationMessage
from sailpoint.beta.models.access_request import AccessRequest
from sailpoint.beta.models.access_request_config import AccessRequestConfig
from sailpoint.beta.models.access_request_dynamic_approver import AccessRequestDynamicApprover
from sailpoint.beta.models.access_request_dynamic_approver1 import AccessRequestDynamicApprover1
from sailpoint.beta.models.access_request_dynamic_approver_requested_items_inner import AccessRequestDynamicApproverRequestedItemsInner
from sailpoint.beta.models.access_request_item import AccessRequestItem
from sailpoint.beta.models.access_request_item_response import AccessRequestItemResponse
from sailpoint.beta.models.access_request_phases import AccessRequestPhases
from sailpoint.beta.models.access_request_post_approval import AccessRequestPostApproval
from sailpoint.beta.models.access_request_post_approval_requested_items_status_inner import AccessRequestPostApprovalRequestedItemsStatusInner
from sailpoint.beta.models.access_request_post_approval_requested_items_status_inner_approval_info_inner import AccessRequestPostApprovalRequestedItemsStatusInnerApprovalInfoInner
from sailpoint.beta.models.access_request_post_approval_requested_items_status_inner_approval_info_inner_approver import AccessRequestPostApprovalRequestedItemsStatusInnerApprovalInfoInnerApprover
from sailpoint.beta.models.access_request_pre_approval import AccessRequestPreApproval
from sailpoint.beta.models.access_request_pre_approval1 import AccessRequestPreApproval1
from sailpoint.beta.models.access_request_pre_approval_requested_items_inner import AccessRequestPreApprovalRequestedItemsInner
from sailpoint.beta.models.access_request_recommendation_action_item_dto import AccessRequestRecommendationActionItemDto
from sailpoint.beta.models.access_request_recommendation_action_item_response_dto import AccessRequestRecommendationActionItemResponseDto
from sailpoint.beta.models.access_request_recommendation_item import AccessRequestRecommendationItem
from sailpoint.beta.models.access_request_recommendation_item_detail import AccessRequestRecommendationItemDetail
from sailpoint.beta.models.access_request_recommendation_item_detail_access import AccessRequestRecommendationItemDetailAccess
from sailpoint.beta.models.access_request_recommendation_item_type import AccessRequestRecommendationItemType
from sailpoint.beta.models.access_request_response import AccessRequestResponse
from sailpoint.beta.models.access_request_type import AccessRequestType
from sailpoint.beta.models.access_requested import AccessRequested
from sailpoint.beta.models.access_type import AccessType
from sailpoint.beta.models.account import Account
from sailpoint.beta.models.account_action import AccountAction
from sailpoint.beta.models.account_activity_item import AccountActivityItem
from sailpoint.beta.models.account_activity_item_operation import AccountActivityItemOperation
from sailpoint.beta.models.account_aggregation import AccountAggregation
from sailpoint.beta.models.account_aggregation_completed import AccountAggregationCompleted
from sailpoint.beta.models.account_aggregation_completed_source import AccountAggregationCompletedSource
from sailpoint.beta.models.account_aggregation_completed_stats import AccountAggregationCompletedStats
from sailpoint.beta.models.account_aggregation_status import AccountAggregationStatus
from sailpoint.beta.models.account_attributes import AccountAttributes
from sailpoint.beta.models.account_attributes_changed import AccountAttributesChanged
from sailpoint.beta.models.account_attributes_changed_account import AccountAttributesChangedAccount
from sailpoint.beta.models.account_attributes_changed_changes_inner import AccountAttributesChangedChangesInner
from sailpoint.beta.models.account_attributes_changed_changes_inner_new_value import AccountAttributesChangedChangesInnerNewValue
from sailpoint.beta.models.account_attributes_changed_changes_inner_old_value import AccountAttributesChangedChangesInnerOldValue
from sailpoint.beta.models.account_attributes_changed_identity import AccountAttributesChangedIdentity
from sailpoint.beta.models.account_attributes_changed_source import AccountAttributesChangedSource
from sailpoint.beta.models.account_attributes_create import AccountAttributesCreate
from sailpoint.beta.models.account_attributes_create_attributes import AccountAttributesCreateAttributes
from sailpoint.beta.models.account_correlated import AccountCorrelated
from sailpoint.beta.models.account_correlated_account import AccountCorrelatedAccount
from sailpoint.beta.models.account_correlated_identity import AccountCorrelatedIdentity
from sailpoint.beta.models.account_correlated_source import AccountCorrelatedSource
from sailpoint.beta.models.account_request_info import AccountRequestInfo
from sailpoint.beta.models.account_status_changed import AccountStatusChanged
from sailpoint.beta.models.account_status_changed_account import AccountStatusChangedAccount
from sailpoint.beta.models.account_status_changed_status_change import AccountStatusChangedStatusChange
from sailpoint.beta.models.account_toggle_request import AccountToggleRequest
from sailpoint.beta.models.account_uncorrelated import AccountUncorrelated
from sailpoint.beta.models.account_uncorrelated_account import AccountUncorrelatedAccount
from sailpoint.beta.models.account_uncorrelated_identity import AccountUncorrelatedIdentity
from sailpoint.beta.models.account_uncorrelated_source import AccountUncorrelatedSource
from sailpoint.beta.models.account_unlock_request import AccountUnlockRequest
from sailpoint.beta.models.account_usage import AccountUsage
from sailpoint.beta.models.accounts_async_result import AccountsAsyncResult
from sailpoint.beta.models.accounts_collected_for_aggregation import AccountsCollectedForAggregation
from sailpoint.beta.models.accounts_collected_for_aggregation_source import AccountsCollectedForAggregationSource
from sailpoint.beta.models.accounts_collected_for_aggregation_stats import AccountsCollectedForAggregationStats
from sailpoint.beta.models.activate_campaign_options import ActivateCampaignOptions
from sailpoint.beta.models.admin_review_reassign import AdminReviewReassign
from sailpoint.beta.models.admin_review_reassign_reassign_to import AdminReviewReassignReassignTo
from sailpoint.beta.models.approval_forward_history import ApprovalForwardHistory
from sailpoint.beta.models.approval_info_response import ApprovalInfoResponse
from sailpoint.beta.models.approval_item_details import ApprovalItemDetails
from sailpoint.beta.models.approval_items import ApprovalItems
from sailpoint.beta.models.approval_reminder_and_escalation_config import ApprovalReminderAndEscalationConfig
from sailpoint.beta.models.approval_scheme import ApprovalScheme
from sailpoint.beta.models.approval_scheme_for_role import ApprovalSchemeForRole
from sailpoint.beta.models.approval_status import ApprovalStatus
from sailpoint.beta.models.approval_status_dto import ApprovalStatusDto
from sailpoint.beta.models.approval_status_dto_current_owner import ApprovalStatusDtoCurrentOwner
from sailpoint.beta.models.approval_status_dto_original_owner import ApprovalStatusDtoOriginalOwner
from sailpoint.beta.models.approval_summary import ApprovalSummary
from sailpoint.beta.models.argument import Argument
from sailpoint.beta.models.array_inner import ArrayInner
from sailpoint.beta.models.attr_sync_source import AttrSyncSource
from sailpoint.beta.models.attr_sync_source_attribute_config import AttrSyncSourceAttributeConfig
from sailpoint.beta.models.attr_sync_source_config import AttrSyncSourceConfig
from sailpoint.beta.models.attribute_change import AttributeChange
from sailpoint.beta.models.attribute_definition import AttributeDefinition
from sailpoint.beta.models.attribute_definition_schema import AttributeDefinitionSchema
from sailpoint.beta.models.attribute_definition_type import AttributeDefinitionType
from sailpoint.beta.models.attributes_changed import AttributesChanged
from sailpoint.beta.models.audit_details import AuditDetails
from sailpoint.beta.models.auth_profile import AuthProfile
from sailpoint.beta.models.auth_profile_request import AuthProfileRequest
from sailpoint.beta.models.auth_profile_summary import AuthProfileSummary
from sailpoint.beta.models.base_common_dto import BaseCommonDto
from sailpoint.beta.models.base_common_dto1 import BaseCommonDto1
from sailpoint.beta.models.base_reference_dto import BaseReferenceDto
from sailpoint.beta.models.basic_auth_config import BasicAuthConfig
from sailpoint.beta.models.bearer_token_auth_config import BearerTokenAuthConfig
from sailpoint.beta.models.before_provisioning_rule_dto import BeforeProvisioningRuleDto
from sailpoint.beta.models.bulk_identities_accounts_response import BulkIdentitiesAccountsResponse
from sailpoint.beta.models.bulk_tagged_object import BulkTaggedObject
from sailpoint.beta.models.bulk_workgroup_members_request_inner import BulkWorkgroupMembersRequestInner
from sailpoint.beta.models.campaign import Campaign
from sailpoint.beta.models.campaign_activated import CampaignActivated
from sailpoint.beta.models.campaign_activated_campaign import CampaignActivatedCampaign
from sailpoint.beta.models.campaign_activated_campaign_campaign_owner import CampaignActivatedCampaignCampaignOwner
from sailpoint.beta.models.campaign_alert import CampaignAlert
from sailpoint.beta.models.campaign_ended import CampaignEnded
from sailpoint.beta.models.campaign_ended_campaign import CampaignEndedCampaign
from sailpoint.beta.models.campaign_generated import CampaignGenerated
from sailpoint.beta.models.campaign_generated_campaign import CampaignGeneratedCampaign
from sailpoint.beta.models.campaign_generated_campaign_campaign_owner import CampaignGeneratedCampaignCampaignOwner
from sailpoint.beta.models.campaign_reference import CampaignReference
from sailpoint.beta.models.campaign_report import CampaignReport
from sailpoint.beta.models.campaign_reports_config import CampaignReportsConfig
from sailpoint.beta.models.campaign_template import CampaignTemplate
from sailpoint.beta.models.campaign_template_owner_ref import CampaignTemplateOwnerRef
from sailpoint.beta.models.cancel_access_request import CancelAccessRequest
from sailpoint.beta.models.cancelable_account_activity import CancelableAccountActivity
from sailpoint.beta.models.cancelled_request_details import CancelledRequestDetails
from sailpoint.beta.models.certification_dto import CertificationDto
from sailpoint.beta.models.certification_phase import CertificationPhase
from sailpoint.beta.models.certification_reference import CertificationReference
from sailpoint.beta.models.certification_reference_dto import CertificationReferenceDto
from sailpoint.beta.models.certification_signed_off import CertificationSignedOff
from sailpoint.beta.models.certification_signed_off_certification import CertificationSignedOffCertification
from sailpoint.beta.models.certification_task import CertificationTask
from sailpoint.beta.models.certifier_response import CertifierResponse
from sailpoint.beta.models.client_log_configuration import ClientLogConfiguration
from sailpoint.beta.models.client_type import ClientType
from sailpoint.beta.models.close_access_request import CloseAccessRequest
from sailpoint.beta.models.comment import Comment
from sailpoint.beta.models.comment_dto import CommentDto
from sailpoint.beta.models.comment_dto1 import CommentDto1
from sailpoint.beta.models.comment_dto1_author import CommentDto1Author
from sailpoint.beta.models.comment_dto_author import CommentDtoAuthor
from sailpoint.beta.models.common_access_id_status import CommonAccessIDStatus
from sailpoint.beta.models.common_access_item_access import CommonAccessItemAccess
from sailpoint.beta.models.common_access_item_request import CommonAccessItemRequest
from sailpoint.beta.models.common_access_item_response import CommonAccessItemResponse
from sailpoint.beta.models.common_access_item_state import CommonAccessItemState
from sailpoint.beta.models.common_access_response import CommonAccessResponse
from sailpoint.beta.models.common_access_type import CommonAccessType
from sailpoint.beta.models.complete_campaign_options import CompleteCampaignOptions
from sailpoint.beta.models.complete_invocation import CompleteInvocation
from sailpoint.beta.models.complete_invocation_input import CompleteInvocationInput
from sailpoint.beta.models.completed_approval import CompletedApproval
from sailpoint.beta.models.completed_approval_pre_approval_trigger_result import CompletedApprovalPreApprovalTriggerResult
from sailpoint.beta.models.completed_approval_reviewed_by import CompletedApprovalReviewedBy
from sailpoint.beta.models.completed_approval_reviewer_comment import CompletedApprovalReviewerComment
from sailpoint.beta.models.completed_approval_state import CompletedApprovalState
from sailpoint.beta.models.completion_status import CompletionStatus
from sailpoint.beta.models.condition_effect import ConditionEffect
from sailpoint.beta.models.condition_effect_config import ConditionEffectConfig
from sailpoint.beta.models.condition_rule import ConditionRule
from sailpoint.beta.models.config_object import ConfigObject
from sailpoint.beta.models.config_type import ConfigType
from sailpoint.beta.models.config_type_enum import ConfigTypeEnum
from sailpoint.beta.models.config_type_enum_camel import ConfigTypeEnumCamel
from sailpoint.beta.models.configuration_details_response import ConfigurationDetailsResponse
from sailpoint.beta.models.configuration_item_request import ConfigurationItemRequest
from sailpoint.beta.models.configuration_item_response import ConfigurationItemResponse
from sailpoint.beta.models.configuration_response import ConfigurationResponse
from sailpoint.beta.models.conflicting_access_criteria import ConflictingAccessCriteria
from sailpoint.beta.models.connected_object import ConnectedObject
from sailpoint.beta.models.connected_object_type import ConnectedObjectType
from sailpoint.beta.models.connector_detail import ConnectorDetail
from sailpoint.beta.models.connector_rule_create_request import ConnectorRuleCreateRequest
from sailpoint.beta.models.connector_rule_create_request_signature import ConnectorRuleCreateRequestSignature
from sailpoint.beta.models.connector_rule_response import ConnectorRuleResponse
from sailpoint.beta.models.connector_rule_update_request import ConnectorRuleUpdateRequest
from sailpoint.beta.models.connector_rule_validation_response import ConnectorRuleValidationResponse
from sailpoint.beta.models.connector_rule_validation_response_details_inner import ConnectorRuleValidationResponseDetailsInner
from sailpoint.beta.models.correlated_governance_event import CorrelatedGovernanceEvent
from sailpoint.beta.models.create_domain_dkim405_response import CreateDomainDkim405Response
from sailpoint.beta.models.create_form_definition_file_request_request import CreateFormDefinitionFileRequestRequest
from sailpoint.beta.models.create_form_definition_request import CreateFormDefinitionRequest
from sailpoint.beta.models.create_form_instance_request import CreateFormInstanceRequest
from sailpoint.beta.models.create_o_auth_client_request import CreateOAuthClientRequest
from sailpoint.beta.models.create_o_auth_client_response import CreateOAuthClientResponse
from sailpoint.beta.models.create_personal_access_token_request import CreatePersonalAccessTokenRequest
from sailpoint.beta.models.create_personal_access_token_response import CreatePersonalAccessTokenResponse
from sailpoint.beta.models.create_workflow_request import CreateWorkflowRequest
from sailpoint.beta.models.custom_password_instruction import CustomPasswordInstruction
from sailpoint.beta.models.delete202_response import Delete202Response
from sailpoint.beta.models.delete_campaigns_request import DeleteCampaignsRequest
from sailpoint.beta.models.delete_non_employee_record_in_bulk_request import DeleteNonEmployeeRecordInBulkRequest
from sailpoint.beta.models.dkim_attributes import DkimAttributes
from sailpoint.beta.models.domain_address import DomainAddress
from sailpoint.beta.models.domain_status_dto import DomainStatusDto
from sailpoint.beta.models.dto_type import DtoType
from sailpoint.beta.models.duo_verification_request import DuoVerificationRequest
from sailpoint.beta.models.email_notification_option import EmailNotificationOption
from sailpoint.beta.models.email_status_dto import EmailStatusDto
from sailpoint.beta.models.entitlement import Entitlement
from sailpoint.beta.models.entitlement_access_request_config import EntitlementAccessRequestConfig
from sailpoint.beta.models.entitlement_approval_scheme import EntitlementApprovalScheme
from sailpoint.beta.models.entitlement_bulk_update_request import EntitlementBulkUpdateRequest
from sailpoint.beta.models.entitlement_manually_updated_fields import EntitlementManuallyUpdatedFields
from sailpoint.beta.models.entitlement_owner import EntitlementOwner
from sailpoint.beta.models.entitlement_ref import EntitlementRef
from sailpoint.beta.models.entitlement_request_config import EntitlementRequestConfig
from sailpoint.beta.models.entitlement_request_config1 import EntitlementRequestConfig1
from sailpoint.beta.models.entitlement_source import EntitlementSource
from sailpoint.beta.models.entity_created_by_dto import EntityCreatedByDTO
from sailpoint.beta.models.error import Error
from sailpoint.beta.models.error_message import ErrorMessage
from sailpoint.beta.models.error_message_dto import ErrorMessageDto
from sailpoint.beta.models.error_response_dto import ErrorResponseDto
from sailpoint.beta.models.evaluate_response import EvaluateResponse
from sailpoint.beta.models.event_bridge_config import EventBridgeConfig
from sailpoint.beta.models.exception_access_criteria import ExceptionAccessCriteria
from sailpoint.beta.models.exception_criteria import ExceptionCriteria
from sailpoint.beta.models.exception_criteria_access import ExceptionCriteriaAccess
from sailpoint.beta.models.exception_criteria_criteria_list_inner import ExceptionCriteriaCriteriaListInner
from sailpoint.beta.models.execution_status import ExecutionStatus
from sailpoint.beta.models.export_form_definitions_by_tenant200_response_inner import ExportFormDefinitionsByTenant200ResponseInner
from sailpoint.beta.models.export_options import ExportOptions
from sailpoint.beta.models.export_payload import ExportPayload
from sailpoint.beta.models.expression import Expression
from sailpoint.beta.models.feature_value_dto import FeatureValueDto
from sailpoint.beta.models.field import Field
from sailpoint.beta.models.field_details import FieldDetails
from sailpoint.beta.models.field_details_dto import FieldDetailsDto
from sailpoint.beta.models.form import Form
from sailpoint.beta.models.form_condition import FormCondition
from sailpoint.beta.models.form_definition_dynamic_schema_request import FormDefinitionDynamicSchemaRequest
from sailpoint.beta.models.form_definition_dynamic_schema_request_attributes import FormDefinitionDynamicSchemaRequestAttributes
from sailpoint.beta.models.form_definition_dynamic_schema_response import FormDefinitionDynamicSchemaResponse
from sailpoint.beta.models.form_definition_file_upload_response import FormDefinitionFileUploadResponse
from sailpoint.beta.models.form_definition_input import FormDefinitionInput
from sailpoint.beta.models.form_definition_response import FormDefinitionResponse
from sailpoint.beta.models.form_details import FormDetails
from sailpoint.beta.models.form_element import FormElement
from sailpoint.beta.models.form_element_data_source_config_options import FormElementDataSourceConfigOptions
from sailpoint.beta.models.form_element_dynamic_data_source import FormElementDynamicDataSource
from sailpoint.beta.models.form_element_dynamic_data_source_config import FormElementDynamicDataSourceConfig
from sailpoint.beta.models.form_element_preview_request import FormElementPreviewRequest
from sailpoint.beta.models.form_error import FormError
from sailpoint.beta.models.form_instance_created_by import FormInstanceCreatedBy
from sailpoint.beta.models.form_instance_recipient import FormInstanceRecipient
from sailpoint.beta.models.form_instance_response import FormInstanceResponse
from sailpoint.beta.models.form_item import FormItem
from sailpoint.beta.models.form_item_details import FormItemDetails
from sailpoint.beta.models.form_owner import FormOwner
from sailpoint.beta.models.form_used_by import FormUsedBy
from sailpoint.beta.models.forward_approval_dto import ForwardApprovalDto
from sailpoint.beta.models.fullcampaign import Fullcampaign
from sailpoint.beta.models.fullcampaign_all_of_filter import FullcampaignAllOfFilter
from sailpoint.beta.models.fullcampaign_all_of_role_composition_campaign_info import FullcampaignAllOfRoleCompositionCampaignInfo
from sailpoint.beta.models.fullcampaign_all_of_role_composition_campaign_info_remediator_ref import FullcampaignAllOfRoleCompositionCampaignInfoRemediatorRef
from sailpoint.beta.models.fullcampaign_all_of_search_campaign_info import FullcampaignAllOfSearchCampaignInfo
from sailpoint.beta.models.fullcampaign_all_of_search_campaign_info_reviewer import FullcampaignAllOfSearchCampaignInfoReviewer
from sailpoint.beta.models.fullcampaign_all_of_source_owner_campaign_info import FullcampaignAllOfSourceOwnerCampaignInfo
from sailpoint.beta.models.fullcampaign_all_of_sources_with_orphan_entitlements import FullcampaignAllOfSourcesWithOrphanEntitlements
from sailpoint.beta.models.get_active_campaigns200_response_inner import GetActiveCampaigns200ResponseInner
from sailpoint.beta.models.get_historical_identity_events200_response_inner import GetHistoricalIdentityEvents200ResponseInner
from sailpoint.beta.models.get_o_auth_client_response import GetOAuthClientResponse
from sailpoint.beta.models.get_personal_access_token_response import GetPersonalAccessTokenResponse
from sailpoint.beta.models.grant_type import GrantType
from sailpoint.beta.models.http_authentication_type import HttpAuthenticationType
from sailpoint.beta.models.http_config import HttpConfig
from sailpoint.beta.models.http_dispatch_mode import HttpDispatchMode
from sailpoint.beta.models.identities_accounts_bulk_request import IdentitiesAccountsBulkRequest
from sailpoint.beta.models.identity import Identity
from sailpoint.beta.models.identity1 import Identity1
from sailpoint.beta.models.identity_association_details import IdentityAssociationDetails
from sailpoint.beta.models.identity_association_details_association_details_inner import IdentityAssociationDetailsAssociationDetailsInner
from sailpoint.beta.models.identity_attribute import IdentityAttribute
from sailpoint.beta.models.identity_attribute_config import IdentityAttributeConfig
from sailpoint.beta.models.identity_attribute_config1 import IdentityAttributeConfig1
from sailpoint.beta.models.identity_attribute_names import IdentityAttributeNames
from sailpoint.beta.models.identity_attribute_preview import IdentityAttributePreview
from sailpoint.beta.models.identity_attribute_transform import IdentityAttributeTransform
from sailpoint.beta.models.identity_attribute_transform1 import IdentityAttributeTransform1
from sailpoint.beta.models.identity_attributes_changed import IdentityAttributesChanged
from sailpoint.beta.models.identity_attributes_changed_changes_inner import IdentityAttributesChangedChangesInner
from sailpoint.beta.models.identity_attributes_changed_changes_inner_new_value import IdentityAttributesChangedChangesInnerNewValue
from sailpoint.beta.models.identity_attributes_changed_changes_inner_old_value import IdentityAttributesChangedChangesInnerOldValue
from sailpoint.beta.models.identity_attributes_changed_changes_inner_old_value_one_of_value import IdentityAttributesChangedChangesInnerOldValueOneOfValue
from sailpoint.beta.models.identity_attributes_changed_identity import IdentityAttributesChangedIdentity
from sailpoint.beta.models.identity_certification_task import IdentityCertificationTask
from sailpoint.beta.models.identity_certified import IdentityCertified
from sailpoint.beta.models.identity_compare_response import IdentityCompareResponse
from sailpoint.beta.models.identity_created import IdentityCreated
from sailpoint.beta.models.identity_created_identity import IdentityCreatedIdentity
from sailpoint.beta.models.identity_deleted import IdentityDeleted
from sailpoint.beta.models.identity_deleted_identity import IdentityDeletedIdentity
from sailpoint.beta.models.identity_dto_lifecycle_state import IdentityDtoLifecycleState
from sailpoint.beta.models.identity_dto_manager_ref import IdentityDtoManagerRef
from sailpoint.beta.models.identity_entities import IdentityEntities
from sailpoint.beta.models.identity_entities_identity_entity import IdentityEntitiesIdentityEntity
from sailpoint.beta.models.identity_exception_report_reference import IdentityExceptionReportReference
from sailpoint.beta.models.identity_exception_report_reference1 import IdentityExceptionReportReference1
from sailpoint.beta.models.identity_history_response import IdentityHistoryResponse
from sailpoint.beta.models.identity_list_item import IdentityListItem
from sailpoint.beta.models.identity_ownership_association_details import IdentityOwnershipAssociationDetails
from sailpoint.beta.models.identity_ownership_association_details_association_details_inner import IdentityOwnershipAssociationDetailsAssociationDetailsInner
from sailpoint.beta.models.identity_preview_request import IdentityPreviewRequest
from sailpoint.beta.models.identity_preview_response import IdentityPreviewResponse
from sailpoint.beta.models.identity_preview_response_identity import IdentityPreviewResponseIdentity
from sailpoint.beta.models.identity_profile import IdentityProfile
from sailpoint.beta.models.identity_profile1 import IdentityProfile1
from sailpoint.beta.models.identity_profile1_all_of_authoritative_source import IdentityProfile1AllOfAuthoritativeSource
from sailpoint.beta.models.identity_profile_all_of_authoritative_source import IdentityProfileAllOfAuthoritativeSource
from sailpoint.beta.models.identity_profile_all_of_owner import IdentityProfileAllOfOwner
from sailpoint.beta.models.identity_profile_exported_object import IdentityProfileExportedObject
from sailpoint.beta.models.identity_reference import IdentityReference
from sailpoint.beta.models.identity_reference_with_id import IdentityReferenceWithId
from sailpoint.beta.models.identity_reference_with_name_and_email import IdentityReferenceWithNameAndEmail
from sailpoint.beta.models.identity_snapshot_summary_response import IdentitySnapshotSummaryResponse
from sailpoint.beta.models.identity_summary import IdentitySummary
from sailpoint.beta.models.identity_sync_job import IdentitySyncJob
from sailpoint.beta.models.identity_sync_payload import IdentitySyncPayload
from sailpoint.beta.models.identity_with_new_access import IdentityWithNewAccess
from sailpoint.beta.models.identity_with_new_access_access_refs_inner import IdentityWithNewAccessAccessRefsInner
from sailpoint.beta.models.import_entitlement_csv_request import ImportEntitlementCsvRequest
from sailpoint.beta.models.import_form_definitions202_response import ImportFormDefinitions202Response
from sailpoint.beta.models.import_form_definitions202_response_errors_inner import ImportFormDefinitions202ResponseErrorsInner
from sailpoint.beta.models.import_object import ImportObject
from sailpoint.beta.models.import_options import ImportOptions
from sailpoint.beta.models.import_sp_config_request import ImportSpConfigRequest
from sailpoint.beta.models.invocation import Invocation
from sailpoint.beta.models.invocation_status import InvocationStatus
from sailpoint.beta.models.invocation_status_type import InvocationStatusType
from sailpoint.beta.models.json_patch import JsonPatch
from sailpoint.beta.models.json_patch_operation import JsonPatchOperation
from sailpoint.beta.models.json_patch_operation_value import JsonPatchOperationValue
from sailpoint.beta.models.kba_answer_request import KbaAnswerRequest
from sailpoint.beta.models.kba_answer_request_item import KbaAnswerRequestItem
from sailpoint.beta.models.kba_auth_response import KbaAuthResponse
from sailpoint.beta.models.kba_auth_response_item import KbaAuthResponseItem
from sailpoint.beta.models.latest_outlier_summary import LatestOutlierSummary
from sailpoint.beta.models.license import License
from sailpoint.beta.models.lifecycle_state import LifecycleState
from sailpoint.beta.models.lifecycle_state_dto import LifecycleStateDto
from sailpoint.beta.models.list_access_profiles401_response import ListAccessProfiles401Response
from sailpoint.beta.models.list_access_profiles429_response import ListAccessProfiles429Response
from sailpoint.beta.models.list_complete_workflow_library200_response_inner import ListCompleteWorkflowLibrary200ResponseInner
from sailpoint.beta.models.list_form_definitions_by_tenant_response import ListFormDefinitionsByTenantResponse
from sailpoint.beta.models.list_form_element_data_by_element_id_response import ListFormElementDataByElementIDResponse
from sailpoint.beta.models.list_form_instances_by_tenant_response import ListFormInstancesByTenantResponse
from sailpoint.beta.models.list_identity_access_items200_response_inner import ListIdentityAccessItems200ResponseInner
from sailpoint.beta.models.list_predefined_select_options_response import ListPredefinedSelectOptionsResponse
from sailpoint.beta.models.list_workgroup_members200_response_inner import ListWorkgroupMembers200ResponseInner
from sailpoint.beta.models.load_entitlement_task import LoadEntitlementTask
from sailpoint.beta.models.locale_origin import LocaleOrigin
from sailpoint.beta.models.localized_message import LocalizedMessage
from sailpoint.beta.models.lookup_step import LookupStep
from sailpoint.beta.models.mail_from_attributes import MailFromAttributes
from sailpoint.beta.models.mail_from_attributes_dto import MailFromAttributesDto
from sailpoint.beta.models.managed_client import ManagedClient
from sailpoint.beta.models.managed_client_status import ManagedClientStatus
from sailpoint.beta.models.managed_client_status_agg_response import ManagedClientStatusAggResponse
from sailpoint.beta.models.managed_client_status_enum import ManagedClientStatusEnum
from sailpoint.beta.models.managed_client_type import ManagedClientType
from sailpoint.beta.models.managed_cluster import ManagedCluster
from sailpoint.beta.models.managed_cluster_attributes import ManagedClusterAttributes
from sailpoint.beta.models.managed_cluster_key_pair import ManagedClusterKeyPair
from sailpoint.beta.models.managed_cluster_queue import ManagedClusterQueue
from sailpoint.beta.models.managed_cluster_redis import ManagedClusterRedis
from sailpoint.beta.models.managed_cluster_types import ManagedClusterTypes
from sailpoint.beta.models.manager_correlation_mapping import ManagerCorrelationMapping
from sailpoint.beta.models.manual_work_item_details import ManualWorkItemDetails
from sailpoint.beta.models.manual_work_item_details_current_owner import ManualWorkItemDetailsCurrentOwner
from sailpoint.beta.models.manual_work_item_details_original_owner import ManualWorkItemDetailsOriginalOwner
from sailpoint.beta.models.manual_work_item_state import ManualWorkItemState
from sailpoint.beta.models.manually_updated_fields_dto import ManuallyUpdatedFieldsDTO
from sailpoint.beta.models.medium import Medium
from sailpoint.beta.models.message_catalog_dto import MessageCatalogDto
from sailpoint.beta.models.metric_response import MetricResponse
from sailpoint.beta.models.mfa_config_test_response import MfaConfigTestResponse
from sailpoint.beta.models.mfa_duo_config import MfaDuoConfig
from sailpoint.beta.models.mfa_okta_config import MfaOktaConfig
from sailpoint.beta.models.model_schema import ModelSchema
from sailpoint.beta.models.multi_policy_request import MultiPolicyRequest
from sailpoint.beta.models.native_change_detection_config import NativeChangeDetectionConfig
from sailpoint.beta.models.non_employee_approval_decision import NonEmployeeApprovalDecision
from sailpoint.beta.models.non_employee_approval_item import NonEmployeeApprovalItem
from sailpoint.beta.models.non_employee_approval_item_base import NonEmployeeApprovalItemBase
from sailpoint.beta.models.non_employee_approval_item_detail import NonEmployeeApprovalItemDetail
from sailpoint.beta.models.non_employee_approval_summary import NonEmployeeApprovalSummary
from sailpoint.beta.models.non_employee_bulk_upload_job import NonEmployeeBulkUploadJob
from sailpoint.beta.models.non_employee_bulk_upload_status import NonEmployeeBulkUploadStatus
from sailpoint.beta.models.non_employee_idn_user_request import NonEmployeeIdnUserRequest
from sailpoint.beta.models.non_employee_record import NonEmployeeRecord
from sailpoint.beta.models.non_employee_reject_approval_decision import NonEmployeeRejectApprovalDecision
from sailpoint.beta.models.non_employee_request import NonEmployeeRequest
from sailpoint.beta.models.non_employee_request_body import NonEmployeeRequestBody
from sailpoint.beta.models.non_employee_request_lite import NonEmployeeRequestLite
from sailpoint.beta.models.non_employee_request_summary import NonEmployeeRequestSummary
from sailpoint.beta.models.non_employee_request_without_approval_item import NonEmployeeRequestWithoutApprovalItem
from sailpoint.beta.models.non_employee_schema_attribute import NonEmployeeSchemaAttribute
from sailpoint.beta.models.non_employee_schema_attribute_body import NonEmployeeSchemaAttributeBody
from sailpoint.beta.models.non_employee_schema_attribute_type import NonEmployeeSchemaAttributeType
from sailpoint.beta.models.non_employee_source import NonEmployeeSource
from sailpoint.beta.models.non_employee_source_lite import NonEmployeeSourceLite
from sailpoint.beta.models.non_employee_source_lite_with_schema_attributes import NonEmployeeSourceLiteWithSchemaAttributes
from sailpoint.beta.models.non_employee_source_request_body import NonEmployeeSourceRequestBody
from sailpoint.beta.models.non_employee_source_with_cloud_external_id import NonEmployeeSourceWithCloudExternalId
from sailpoint.beta.models.non_employee_source_with_ne_count import NonEmployeeSourceWithNECount
from sailpoint.beta.models.notification_template_context import NotificationTemplateContext
from sailpoint.beta.models.object_export_import_options import ObjectExportImportOptions
from sailpoint.beta.models.object_import_result import ObjectImportResult
from sailpoint.beta.models.okta_verification_request import OktaVerificationRequest
from sailpoint.beta.models.org_config import OrgConfig
from sailpoint.beta.models.outlier import Outlier
from sailpoint.beta.models.outlier_contributing_feature import OutlierContributingFeature
from sailpoint.beta.models.outlier_contributing_feature_value import OutlierContributingFeatureValue
from sailpoint.beta.models.outlier_feature_summary import OutlierFeatureSummary
from sailpoint.beta.models.outlier_feature_summary_outlier_feature_display_values_inner import OutlierFeatureSummaryOutlierFeatureDisplayValuesInner
from sailpoint.beta.models.outlier_feature_translation import OutlierFeatureTranslation
from sailpoint.beta.models.outlier_summary import OutlierSummary
from sailpoint.beta.models.outliers_contributing_feature_access_items import OutliersContributingFeatureAccessItems
from sailpoint.beta.models.owner_dto import OwnerDto
from sailpoint.beta.models.owner_reference import OwnerReference
from sailpoint.beta.models.owner_reference_dto import OwnerReferenceDto
from sailpoint.beta.models.owner_reference_segments import OwnerReferenceSegments
from sailpoint.beta.models.password_change_request import PasswordChangeRequest
from sailpoint.beta.models.password_change_response import PasswordChangeResponse
from sailpoint.beta.models.password_digit_token import PasswordDigitToken
from sailpoint.beta.models.password_digit_token_reset import PasswordDigitTokenReset
from sailpoint.beta.models.password_info import PasswordInfo
from sailpoint.beta.models.password_info_account import PasswordInfoAccount
from sailpoint.beta.models.password_info_query_dto import PasswordInfoQueryDTO
from sailpoint.beta.models.password_org_config import PasswordOrgConfig
from sailpoint.beta.models.password_status import PasswordStatus
from sailpoint.beta.models.password_sync_group import PasswordSyncGroup
from sailpoint.beta.models.pat_owner import PatOwner
from sailpoint.beta.models.patch_potential_role_request_inner import PatchPotentialRoleRequestInner
from sailpoint.beta.models.patch_service_desk_integration_request import PatchServiceDeskIntegrationRequest
from sailpoint.beta.models.peer_group_member import PeerGroupMember
from sailpoint.beta.models.pending_approval import PendingApproval
from sailpoint.beta.models.pending_approval_action import PendingApprovalAction
from sailpoint.beta.models.permission_dto import PermissionDto
from sailpoint.beta.models.post_external_execute_workflow200_response import PostExternalExecuteWorkflow200Response
from sailpoint.beta.models.post_external_execute_workflow_request import PostExternalExecuteWorkflowRequest
from sailpoint.beta.models.pre_approval_trigger_details import PreApprovalTriggerDetails
from sailpoint.beta.models.preferences_dto import PreferencesDto
from sailpoint.beta.models.preview_data_source_response import PreviewDataSourceResponse
from sailpoint.beta.models.process_identities_request import ProcessIdentitiesRequest
from sailpoint.beta.models.product import Product
from sailpoint.beta.models.provisioning_completed import ProvisioningCompleted
from sailpoint.beta.models.provisioning_completed_account_requests_inner import ProvisioningCompletedAccountRequestsInner
from sailpoint.beta.models.provisioning_completed_account_requests_inner_attribute_requests_inner import ProvisioningCompletedAccountRequestsInnerAttributeRequestsInner
from sailpoint.beta.models.provisioning_completed_account_requests_inner_source import ProvisioningCompletedAccountRequestsInnerSource
from sailpoint.beta.models.provisioning_completed_recipient import ProvisioningCompletedRecipient
from sailpoint.beta.models.provisioning_completed_requester import ProvisioningCompletedRequester
from sailpoint.beta.models.provisioning_config import ProvisioningConfig
from sailpoint.beta.models.provisioning_config_managed_resource_refs_inner import ProvisioningConfigManagedResourceRefsInner
from sailpoint.beta.models.provisioning_config_plan_initializer_script import ProvisioningConfigPlanInitializerScript
from sailpoint.beta.models.provisioning_criteria_level1 import ProvisioningCriteriaLevel1
from sailpoint.beta.models.provisioning_criteria_level2 import ProvisioningCriteriaLevel2
from sailpoint.beta.models.provisioning_criteria_level3 import ProvisioningCriteriaLevel3
from sailpoint.beta.models.provisioning_criteria_operation import ProvisioningCriteriaOperation
from sailpoint.beta.models.provisioning_details import ProvisioningDetails
from sailpoint.beta.models.provisioning_policy_dto import ProvisioningPolicyDto
from sailpoint.beta.models.provisioning_state import ProvisioningState
from sailpoint.beta.models.public_identity_attribute_config import PublicIdentityAttributeConfig
from sailpoint.beta.models.public_identity_config import PublicIdentityConfig
from sailpoint.beta.models.put_password_dictionary_request import PutPasswordDictionaryRequest
from sailpoint.beta.models.queued_check_config_details import QueuedCheckConfigDetails
from sailpoint.beta.models.reassign_reference import ReassignReference
from sailpoint.beta.models.reassignment import Reassignment
from sailpoint.beta.models.reassignment_type import ReassignmentType
from sailpoint.beta.models.reassignment_type_enum import ReassignmentTypeEnum
from sailpoint.beta.models.recommendation_config_dto import RecommendationConfigDto
from sailpoint.beta.models.recommendation_request import RecommendationRequest
from sailpoint.beta.models.recommendation_request_dto import RecommendationRequestDto
from sailpoint.beta.models.recommendation_response import RecommendationResponse
from sailpoint.beta.models.recommendation_response_dto import RecommendationResponseDto
from sailpoint.beta.models.recommender_calculations import RecommenderCalculations
from sailpoint.beta.models.recommender_calculations_identity_attributes_value import RecommenderCalculationsIdentityAttributesValue
from sailpoint.beta.models.remediation_item_details import RemediationItemDetails
from sailpoint.beta.models.remediation_items import RemediationItems
from sailpoint.beta.models.report_config_dto import ReportConfigDTO
from sailpoint.beta.models.report_result_reference import ReportResultReference
from sailpoint.beta.models.report_type import ReportType
from sailpoint.beta.models.request_on_behalf_of_config import RequestOnBehalfOfConfig
from sailpoint.beta.models.requestability import Requestability
from sailpoint.beta.models.requestability_for_role import RequestabilityForRole
from sailpoint.beta.models.requestable_object import RequestableObject
from sailpoint.beta.models.requestable_object_reference import RequestableObjectReference
from sailpoint.beta.models.requestable_object_request_status import RequestableObjectRequestStatus
from sailpoint.beta.models.requestable_object_type import RequestableObjectType
from sailpoint.beta.models.requested_item_status import RequestedItemStatus
from sailpoint.beta.models.requested_item_status_cancelled_request_details import RequestedItemStatusCancelledRequestDetails
from sailpoint.beta.models.requested_item_status_pre_approval_trigger_details import RequestedItemStatusPreApprovalTriggerDetails
from sailpoint.beta.models.requested_item_status_provisioning_details import RequestedItemStatusProvisioningDetails
from sailpoint.beta.models.requested_item_status_request_state import RequestedItemStatusRequestState
from sailpoint.beta.models.requested_item_status_requester_comment import RequestedItemStatusRequesterComment
from sailpoint.beta.models.requested_item_status_sod_violation_context import RequestedItemStatusSodViolationContext
from sailpoint.beta.models.resource_bundle_message import ResourceBundleMessage
from sailpoint.beta.models.resource_object import ResourceObject
from sailpoint.beta.models.resource_objects_request import ResourceObjectsRequest
from sailpoint.beta.models.resource_objects_response import ResourceObjectsResponse
from sailpoint.beta.models.review_reassign import ReviewReassign
from sailpoint.beta.models.reviewer import Reviewer
from sailpoint.beta.models.revocability import Revocability
from sailpoint.beta.models.revocability_for_role import RevocabilityForRole
from sailpoint.beta.models.role import Role
from sailpoint.beta.models.role_assignment_source_type import RoleAssignmentSourceType
from sailpoint.beta.models.role_bulk_delete_request import RoleBulkDeleteRequest
from sailpoint.beta.models.role_criteria_key import RoleCriteriaKey
from sailpoint.beta.models.role_criteria_key_type import RoleCriteriaKeyType
from sailpoint.beta.models.role_criteria_level1 import RoleCriteriaLevel1
from sailpoint.beta.models.role_criteria_level2 import RoleCriteriaLevel2
from sailpoint.beta.models.role_criteria_level3 import RoleCriteriaLevel3
from sailpoint.beta.models.role_criteria_operation import RoleCriteriaOperation
from sailpoint.beta.models.role_identity import RoleIdentity
from sailpoint.beta.models.role_insight import RoleInsight
from sailpoint.beta.models.role_insights_entitlement import RoleInsightsEntitlement
from sailpoint.beta.models.role_insights_entitlement_changes import RoleInsightsEntitlementChanges
from sailpoint.beta.models.role_insights_identities import RoleInsightsIdentities
from sailpoint.beta.models.role_insights_insight import RoleInsightsInsight
from sailpoint.beta.models.role_insights_response import RoleInsightsResponse
from sailpoint.beta.models.role_insights_role import RoleInsightsRole
from sailpoint.beta.models.role_insights_summary import RoleInsightsSummary
from sailpoint.beta.models.role_membership_identity import RoleMembershipIdentity
from sailpoint.beta.models.role_membership_selector import RoleMembershipSelector
from sailpoint.beta.models.role_membership_selector_type import RoleMembershipSelectorType
from sailpoint.beta.models.role_mining_entitlement import RoleMiningEntitlement
from sailpoint.beta.models.role_mining_entitlement_ref import RoleMiningEntitlementRef
from sailpoint.beta.models.role_mining_identity import RoleMiningIdentity
from sailpoint.beta.models.role_mining_identity_distribution import RoleMiningIdentityDistribution
from sailpoint.beta.models.role_mining_potential_role import RoleMiningPotentialRole
from sailpoint.beta.models.role_mining_potential_role_application import RoleMiningPotentialRoleApplication
from sailpoint.beta.models.role_mining_potential_role_edit_entitlements import RoleMiningPotentialRoleEditEntitlements
from sailpoint.beta.models.role_mining_potential_role_export_request import RoleMiningPotentialRoleExportRequest
from sailpoint.beta.models.role_mining_potential_role_export_response import RoleMiningPotentialRoleExportResponse
from sailpoint.beta.models.role_mining_potential_role_export_state import RoleMiningPotentialRoleExportState
from sailpoint.beta.models.role_mining_potential_role_provision_request import RoleMiningPotentialRoleProvisionRequest
from sailpoint.beta.models.role_mining_potential_role_provision_state import RoleMiningPotentialRoleProvisionState
from sailpoint.beta.models.role_mining_potential_role_ref import RoleMiningPotentialRoleRef
from sailpoint.beta.models.role_mining_potential_role_source_usage import RoleMiningPotentialRoleSourceUsage
from sailpoint.beta.models.role_mining_potential_role_summary import RoleMiningPotentialRoleSummary
from sailpoint.beta.models.role_mining_role_type import RoleMiningRoleType
from sailpoint.beta.models.role_mining_session_draft_role_dto import RoleMiningSessionDraftRoleDto
from sailpoint.beta.models.role_mining_session_dto import RoleMiningSessionDto
from sailpoint.beta.models.role_mining_session_dto_created_by import RoleMiningSessionDtoCreatedBy
from sailpoint.beta.models.role_mining_session_parameters_dto import RoleMiningSessionParametersDto
from sailpoint.beta.models.role_mining_session_response import RoleMiningSessionResponse
from sailpoint.beta.models.role_mining_session_scope import RoleMiningSessionScope
from sailpoint.beta.models.role_mining_session_scoping_method import RoleMiningSessionScopingMethod
from sailpoint.beta.models.role_mining_session_state import RoleMiningSessionState
from sailpoint.beta.models.role_mining_session_status import RoleMiningSessionStatus
from sailpoint.beta.models.saved_search_complete import SavedSearchComplete
from sailpoint.beta.models.saved_search_complete_search_results import SavedSearchCompleteSearchResults
from sailpoint.beta.models.saved_search_complete_search_results_account import SavedSearchCompleteSearchResultsAccount
from sailpoint.beta.models.saved_search_complete_search_results_entitlement import SavedSearchCompleteSearchResultsEntitlement
from sailpoint.beta.models.saved_search_complete_search_results_identity import SavedSearchCompleteSearchResultsIdentity
from sailpoint.beta.models.schedule import Schedule
from sailpoint.beta.models.schedule1 import Schedule1
from sailpoint.beta.models.schedule1_days import Schedule1Days
from sailpoint.beta.models.schedule1_hours import Schedule1Hours
from sailpoint.beta.models.schedule1_months import Schedule1Months
from sailpoint.beta.models.schedule_days import ScheduleDays
from sailpoint.beta.models.schedule_hours import ScheduleHours
from sailpoint.beta.models.schedule_months import ScheduleMonths
from sailpoint.beta.models.schedule_type import ScheduleType
from sailpoint.beta.models.search_attribute_config import SearchAttributeConfig
from sailpoint.beta.models.search_form_definitions_by_tenant400_response import SearchFormDefinitionsByTenant400Response
from sailpoint.beta.models.section import Section
from sailpoint.beta.models.section_details import SectionDetails
from sailpoint.beta.models.segment import Segment
from sailpoint.beta.models.selector import Selector
from sailpoint.beta.models.selector_type import SelectorType
from sailpoint.beta.models.self_import_export_dto import SelfImportExportDto
from sailpoint.beta.models.send_test_notification_request_dto import SendTestNotificationRequestDto
from sailpoint.beta.models.send_token_request import SendTokenRequest
from sailpoint.beta.models.send_token_response import SendTokenResponse
from sailpoint.beta.models.service_desk_integration_dto import ServiceDeskIntegrationDto
from sailpoint.beta.models.service_desk_integration_dto_all_of_before_provisioning_rule import ServiceDeskIntegrationDtoAllOfBeforeProvisioningRule
from sailpoint.beta.models.service_desk_integration_dto_all_of_cluster_ref import ServiceDeskIntegrationDtoAllOfClusterRef
from sailpoint.beta.models.service_desk_integration_dto_all_of_owner_ref import ServiceDeskIntegrationDtoAllOfOwnerRef
from sailpoint.beta.models.service_desk_integration_template_dto import ServiceDeskIntegrationTemplateDto
from sailpoint.beta.models.service_desk_integration_template_type import ServiceDeskIntegrationTemplateType
from sailpoint.beta.models.service_desk_source import ServiceDeskSource
from sailpoint.beta.models.slimcampaign import Slimcampaign
from sailpoint.beta.models.sod_exempt_criteria import SodExemptCriteria
from sailpoint.beta.models.sod_exempt_criteria1 import SodExemptCriteria1
from sailpoint.beta.models.sod_policy import SodPolicy
from sailpoint.beta.models.sod_policy_conflicting_access_criteria import SodPolicyConflictingAccessCriteria
from sailpoint.beta.models.sod_policy_dto import SodPolicyDto
from sailpoint.beta.models.sod_policy_schedule import SodPolicySchedule
from sailpoint.beta.models.sod_recipient import SodRecipient
from sailpoint.beta.models.sod_report_result_dto import SodReportResultDto
from sailpoint.beta.models.sod_violation_check_result import SodViolationCheckResult
from sailpoint.beta.models.sod_violation_check_result1 import SodViolationCheckResult1
from sailpoint.beta.models.sod_violation_context import SodViolationContext
from sailpoint.beta.models.sod_violation_context1 import SodViolationContext1
from sailpoint.beta.models.sod_violation_context1_conflicting_access_criteria import SodViolationContext1ConflictingAccessCriteria
from sailpoint.beta.models.sod_violation_context1_conflicting_access_criteria_left_criteria import SodViolationContext1ConflictingAccessCriteriaLeftCriteria
from sailpoint.beta.models.sod_violation_context_check_completed import SodViolationContextCheckCompleted
from sailpoint.beta.models.sod_violation_context_check_completed1 import SodViolationContextCheckCompleted1
from sailpoint.beta.models.sod_violation_context_conflicting_access_criteria import SodViolationContextConflictingAccessCriteria
from sailpoint.beta.models.sod_violation_context_conflicting_access_criteria_left_criteria import SodViolationContextConflictingAccessCriteriaLeftCriteria
from sailpoint.beta.models.source import Source
from sailpoint.beta.models.source1 import Source1
from sailpoint.beta.models.source_account_correlation_config import SourceAccountCorrelationConfig
from sailpoint.beta.models.source_account_correlation_rule import SourceAccountCorrelationRule
from sailpoint.beta.models.source_account_created import SourceAccountCreated
from sailpoint.beta.models.source_account_deleted import SourceAccountDeleted
from sailpoint.beta.models.source_account_updated import SourceAccountUpdated
from sailpoint.beta.models.source_before_provisioning_rule import SourceBeforeProvisioningRule
from sailpoint.beta.models.source_cluster import SourceCluster
from sailpoint.beta.models.source_cluster_dto import SourceClusterDto
from sailpoint.beta.models.source_code import SourceCode
from sailpoint.beta.models.source_created import SourceCreated
from sailpoint.beta.models.source_created_actor import SourceCreatedActor
from sailpoint.beta.models.source_deleted import SourceDeleted
from sailpoint.beta.models.source_deleted_actor import SourceDeletedActor
from sailpoint.beta.models.source_entitlement_request_config import SourceEntitlementRequestConfig
from sailpoint.beta.models.source_feature import SourceFeature
from sailpoint.beta.models.source_management_workgroup import SourceManagementWorkgroup
from sailpoint.beta.models.source_manager_correlation_rule import SourceManagerCorrelationRule
from sailpoint.beta.models.source_owner import SourceOwner
from sailpoint.beta.models.source_password_policies_inner import SourcePasswordPoliciesInner
from sailpoint.beta.models.source_schemas_inner import SourceSchemasInner
from sailpoint.beta.models.source_sync_job import SourceSyncJob
from sailpoint.beta.models.source_sync_payload import SourceSyncPayload
from sailpoint.beta.models.source_updated import SourceUpdated
from sailpoint.beta.models.source_updated_actor import SourceUpdatedActor
from sailpoint.beta.models.source_usage import SourceUsage
from sailpoint.beta.models.source_usage_status import SourceUsageStatus
from sailpoint.beta.models.sp_config_export_job import SpConfigExportJob
from sailpoint.beta.models.sp_config_export_job_status import SpConfigExportJobStatus
from sailpoint.beta.models.sp_config_export_results import SpConfigExportResults
from sailpoint.beta.models.sp_config_import_job_status import SpConfigImportJobStatus
from sailpoint.beta.models.sp_config_import_results import SpConfigImportResults
from sailpoint.beta.models.sp_config_job import SpConfigJob
from sailpoint.beta.models.sp_config_message import SpConfigMessage
from sailpoint.beta.models.sp_config_object import SpConfigObject
from sailpoint.beta.models.sp_config_url import SpConfigUrl
from sailpoint.beta.models.standard_level import StandardLevel
from sailpoint.beta.models.start_invocation_input import StartInvocationInput
from sailpoint.beta.models.status_response import StatusResponse
from sailpoint.beta.models.subscription import Subscription
from sailpoint.beta.models.subscription_patch_request_inner import SubscriptionPatchRequestInner
from sailpoint.beta.models.subscription_patch_request_inner_value import SubscriptionPatchRequestInnerValue
from sailpoint.beta.models.subscription_patch_request_inner_value_any_of_inner import SubscriptionPatchRequestInnerValueAnyOfInner
from sailpoint.beta.models.subscription_post_request import SubscriptionPostRequest
from sailpoint.beta.models.subscription_put_request import SubscriptionPutRequest
from sailpoint.beta.models.subscription_type import SubscriptionType
from sailpoint.beta.models.tagged_object import TaggedObject
from sailpoint.beta.models.tagged_object_dto import TaggedObjectDto
from sailpoint.beta.models.tagged_object_object_ref import TaggedObjectObjectRef
from sailpoint.beta.models.task_result_dto import TaskResultDto
from sailpoint.beta.models.task_result_response import TaskResultResponse
from sailpoint.beta.models.task_result_simplified import TaskResultSimplified
from sailpoint.beta.models.task_return_details import TaskReturnDetails
from sailpoint.beta.models.task_status import TaskStatus
from sailpoint.beta.models.task_status_message import TaskStatusMessage
from sailpoint.beta.models.template_bulk_delete_dto import TemplateBulkDeleteDto
from sailpoint.beta.models.template_dto import TemplateDto
from sailpoint.beta.models.template_dto_default import TemplateDtoDefault
from sailpoint.beta.models.tenant import Tenant
from sailpoint.beta.models.tenant_configuration_details import TenantConfigurationDetails
from sailpoint.beta.models.tenant_configuration_request import TenantConfigurationRequest
from sailpoint.beta.models.tenant_configuration_response import TenantConfigurationResponse
from sailpoint.beta.models.test_external_execute_workflow200_response import TestExternalExecuteWorkflow200Response
from sailpoint.beta.models.test_external_execute_workflow_request import TestExternalExecuteWorkflowRequest
from sailpoint.beta.models.test_invocation import TestInvocation
from sailpoint.beta.models.test_workflow200_response import TestWorkflow200Response
from sailpoint.beta.models.test_workflow_request import TestWorkflowRequest
from sailpoint.beta.models.token_auth_request import TokenAuthRequest
from sailpoint.beta.models.token_auth_response import TokenAuthResponse
from sailpoint.beta.models.transform import Transform
from sailpoint.beta.models.transform_definition import TransformDefinition
from sailpoint.beta.models.transform_definition1 import TransformDefinition1
from sailpoint.beta.models.transform_definition1_attributes_value import TransformDefinition1AttributesValue
from sailpoint.beta.models.transform_read import TransformRead
from sailpoint.beta.models.translation_message import TranslationMessage
from sailpoint.beta.models.trigger import Trigger
from sailpoint.beta.models.trigger_example_input import TriggerExampleInput
from sailpoint.beta.models.trigger_example_output import TriggerExampleOutput
from sailpoint.beta.models.trigger_type import TriggerType
from sailpoint.beta.models.update_access_profiles_in_bulk412_response import UpdateAccessProfilesInBulk412Response
from sailpoint.beta.models.usage_type import UsageType
from sailpoint.beta.models.v3_connector_dto import V3ConnectorDto
from sailpoint.beta.models.va_cluster_status_change_event import VAClusterStatusChangeEvent
from sailpoint.beta.models.va_cluster_status_change_event_application import VAClusterStatusChangeEventApplication
from sailpoint.beta.models.va_cluster_status_change_event_health_check_result import VAClusterStatusChangeEventHealthCheckResult
from sailpoint.beta.models.va_cluster_status_change_event_previous_health_check_result import VAClusterStatusChangeEventPreviousHealthCheckResult
from sailpoint.beta.models.validate_filter_input_dto import ValidateFilterInputDto
from sailpoint.beta.models.validate_filter_output_dto import ValidateFilterOutputDto
from sailpoint.beta.models.value import Value
from sailpoint.beta.models.verification_poll_request import VerificationPollRequest
from sailpoint.beta.models.verification_response import VerificationResponse
from sailpoint.beta.models.violation_context import ViolationContext
from sailpoint.beta.models.violation_context_policy import ViolationContextPolicy
from sailpoint.beta.models.violation_owner_assignment_config import ViolationOwnerAssignmentConfig
from sailpoint.beta.models.violation_owner_assignment_config_owner_ref import ViolationOwnerAssignmentConfigOwnerRef
from sailpoint.beta.models.violation_prediction import ViolationPrediction
from sailpoint.beta.models.visibility_criteria import VisibilityCriteria
from sailpoint.beta.models.work_item_forward import WorkItemForward
from sailpoint.beta.models.work_item_state import WorkItemState
from sailpoint.beta.models.work_item_type import WorkItemType
from sailpoint.beta.models.work_items import WorkItems
from sailpoint.beta.models.work_items_count import WorkItemsCount
from sailpoint.beta.models.work_items_summary import WorkItemsSummary
from sailpoint.beta.models.workflow import Workflow
from sailpoint.beta.models.workflow_all_of_creator import WorkflowAllOfCreator
from sailpoint.beta.models.workflow_body import WorkflowBody
from sailpoint.beta.models.workflow_body_owner import WorkflowBodyOwner
from sailpoint.beta.models.workflow_definition import WorkflowDefinition
from sailpoint.beta.models.workflow_execution import WorkflowExecution
from sailpoint.beta.models.workflow_execution_event import WorkflowExecutionEvent
from sailpoint.beta.models.workflow_library_action import WorkflowLibraryAction
from sailpoint.beta.models.workflow_library_form_fields import WorkflowLibraryFormFields
from sailpoint.beta.models.workflow_library_operator import WorkflowLibraryOperator
from sailpoint.beta.models.workflow_library_trigger import WorkflowLibraryTrigger
from sailpoint.beta.models.workflow_o_auth_client import WorkflowOAuthClient
from sailpoint.beta.models.workflow_trigger import WorkflowTrigger
from sailpoint.beta.models.workgroup_bulk_delete_request import WorkgroupBulkDeleteRequest
from sailpoint.beta.models.workgroup_connection_dto import WorkgroupConnectionDto
from sailpoint.beta.models.workgroup_delete_item import WorkgroupDeleteItem
from sailpoint.beta.models.workgroup_dto import WorkgroupDto
from sailpoint.beta.models.workgroup_member_add_item import WorkgroupMemberAddItem
from sailpoint.beta.models.workgroup_member_delete_item import WorkgroupMemberDeleteItem



# coding: utf-8

"""
    IdentityNow Beta API

    Use these APIs to interact with the IdentityNow platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, ClassVar, Dict, List
from pydantic import BaseModel, StrictInt, StrictStr, field_validator
from pydantic import Field
from sailpoint.beta.models.task_return_details import TaskReturnDetails
from sailpoint.beta.models.task_status_message import TaskStatusMessage
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class TaskStatus(BaseModel):
    """
    Details and current status of a specific task
    """ # noqa: E501
    id: StrictStr = Field(description="System-generated unique ID of the task this TaskStatus represents")
    type: StrictStr = Field(description="Type of task this TaskStatus represents")
    unique_name: StrictStr = Field(description="Name of the task this TaskStatus represents", alias="uniqueName")
    description: StrictStr = Field(description="Description of the task this TaskStatus represents")
    parent_name: StrictStr = Field(description="Name of the parent of the task this TaskStatus represents", alias="parentName")
    launcher: StrictStr = Field(description="Service to execute the task this TaskStatus represents")
    created: datetime = Field(description="Creation date of the task this TaskStatus represents")
    modified: datetime = Field(description="Last modification date of the task this TaskStatus represents")
    launched: datetime = Field(description="Launch date of the task this TaskStatus represents")
    completed: datetime = Field(description="Completion date of the task this TaskStatus represents")
    completion_status: StrictStr = Field(description="Completion status of the task this TaskStatus represents", alias="completionStatus")
    messages: List[TaskStatusMessage] = Field(description="Messages associated with the task this TaskStatus represents")
    returns: List[TaskReturnDetails] = Field(description="Return values from the task this TaskStatus represents")
    attributes: Dict[str, Any] = Field(description="Attributes of the task this TaskStatus represents")
    progress: StrictStr = Field(description="Current progress of the task this TaskStatus represents")
    percent_complete: StrictInt = Field(description="Current percentage completion of the task this TaskStatus represents", alias="percentComplete")
    __properties: ClassVar[List[str]] = ["id", "type", "uniqueName", "description", "parentName", "launcher", "created", "modified", "launched", "completed", "completionStatus", "messages", "returns", "attributes", "progress", "percentComplete"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('QUARTZ', 'QPOC', 'QUEUED_TASK'):
            raise ValueError("must be one of enum values ('QUARTZ', 'QPOC', 'QUEUED_TASK')")
        return value

    @field_validator('completion_status')
    def completion_status_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('Success', 'Warning', 'Error', 'Terminated', 'TempError'):
            raise ValueError("must be one of enum values ('Success', 'Warning', 'Error', 'Terminated', 'TempError')")
        return value

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TaskStatus from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in messages (list)
        _items = []
        if self.messages:
            for _item in self.messages:
                if _item:
                    _items.append(_item.to_dict())
            _dict['messages'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in returns (list)
        _items = []
        if self.returns:
            for _item in self.returns:
                if _item:
                    _items.append(_item.to_dict())
            _dict['returns'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of TaskStatus from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "type": obj.get("type"),
            "uniqueName": obj.get("uniqueName"),
            "description": obj.get("description"),
            "parentName": obj.get("parentName"),
            "launcher": obj.get("launcher"),
            "created": obj.get("created"),
            "modified": obj.get("modified"),
            "launched": obj.get("launched"),
            "completed": obj.get("completed"),
            "completionStatus": obj.get("completionStatus"),
            "messages": [TaskStatusMessage.from_dict(_item) for _item in obj.get("messages")] if obj.get("messages") is not None else None,
            "returns": [TaskReturnDetails.from_dict(_item) for _item in obj.get("returns")] if obj.get("returns") is not None else None,
            "attributes": obj.get("attributes"),
            "progress": obj.get("progress"),
            "percentComplete": obj.get("percentComplete")
        })
        return _obj





# coding: utf-8

"""
    IdentityNow Beta API

    Use these APIs to interact with the IdentityNow platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictStr, field_validator
from pydantic import Field
from sailpoint.beta.models.license import License
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class Product(BaseModel):
    """
    Product
    """ # noqa: E501
    product_name: Optional[StrictStr] = Field(default=None, description="Name of the Product", alias="productName")
    url: Optional[StrictStr] = Field(default=None, description="URL of the Product")
    product_tenant_id: Optional[StrictStr] = Field(default=None, description="An identifier for a specific product-tenant combination", alias="productTenantId")
    product_region: Optional[StrictStr] = Field(default=None, description="Product region", alias="productRegion")
    product_right: Optional[StrictStr] = Field(default=None, description="Right needed for the Product", alias="productRight")
    api_url: Optional[StrictStr] = Field(default=None, description="API URL of the Product", alias="apiUrl")
    licenses: Optional[List[License]] = None
    attributes: Optional[Dict[str, Any]] = Field(default=None, description="Additional attributes for a product")
    zone: Optional[StrictStr] = Field(default=None, description="Zone")
    status: Optional[StrictStr] = Field(default=None, description="Status of the product")
    status_date_time: Optional[datetime] = Field(default=None, description="Status datetime", alias="statusDateTime")
    reason: Optional[StrictStr] = Field(default=None, description="If there's a tenant provisioning failure then reason will have the description of error")
    notes: Optional[StrictStr] = Field(default=None, description="Product could have additional notes added during tenant provisioning.")
    date_created: Optional[datetime] = Field(default=None, description="Date when the product was created", alias="dateCreated")
    last_updated: Optional[datetime] = Field(default=None, description="Date when the product was last updated", alias="lastUpdated")
    org_type: Optional[StrictStr] = Field(default=None, description="Type of org", alias="orgType")
    __properties: ClassVar[List[str]] = ["productName", "url", "productTenantId", "productRegion", "productRight", "apiUrl", "licenses", "attributes", "zone", "status", "statusDateTime", "reason", "notes", "dateCreated", "lastUpdated", "orgType"]

    @field_validator('org_type')
    def org_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('development', 'staging', 'production', 'test', 'partner', 'training', 'demonstration', 'sandbox', 'null'):
            raise ValueError("must be one of enum values ('development', 'staging', 'production', 'test', 'partner', 'training', 'demonstration', 'sandbox', 'null')")
        return value

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of Product from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in licenses (list)
        _items = []
        if self.licenses:
            for _item in self.licenses:
                if _item:
                    _items.append(_item.to_dict())
            _dict['licenses'] = _items
        # set to None if api_url (nullable) is None
        # and model_fields_set contains the field
        if self.api_url is None and "api_url" in self.model_fields_set:
            _dict['apiUrl'] = None

        # set to None if date_created (nullable) is None
        # and model_fields_set contains the field
        if self.date_created is None and "date_created" in self.model_fields_set:
            _dict['dateCreated'] = None

        # set to None if last_updated (nullable) is None
        # and model_fields_set contains the field
        if self.last_updated is None and "last_updated" in self.model_fields_set:
            _dict['lastUpdated'] = None

        # set to None if org_type (nullable) is None
        # and model_fields_set contains the field
        if self.org_type is None and "org_type" in self.model_fields_set:
            _dict['orgType'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of Product from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "productName": obj.get("productName"),
            "url": obj.get("url"),
            "productTenantId": obj.get("productTenantId"),
            "productRegion": obj.get("productRegion"),
            "productRight": obj.get("productRight"),
            "apiUrl": obj.get("apiUrl"),
            "licenses": [License.from_dict(_item) for _item in obj.get("licenses")] if obj.get("licenses") is not None else None,
            "attributes": obj.get("attributes"),
            "zone": obj.get("zone"),
            "status": obj.get("status"),
            "statusDateTime": obj.get("statusDateTime"),
            "reason": obj.get("reason"),
            "notes": obj.get("notes"),
            "dateCreated": obj.get("dateCreated"),
            "lastUpdated": obj.get("lastUpdated"),
            "orgType": obj.get("orgType")
        })
        return _obj





# coding: utf-8

"""
    IdentityNow Beta API

    Use these APIs to interact with the IdentityNow platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.public_identities_config_api import PublicIdentitiesConfigApi


class TestPublicIdentitiesConfigApi(unittest.TestCase):
    """PublicIdentitiesConfigApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PublicIdentitiesConfigApi()

    def tearDown(self) -> None:
        pass

    def test_get_public_identity_config(self) -> None:
        """Test case for get_public_identity_config

        Get Public Identity Config
        """
        pass

    def test_update_public_identity_config(self) -> None:
        """Test case for update_public_identity_config

        Update Public Identity Config
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    IdentityNow Beta API

    Use these APIs to interact with the IdentityNow platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictStr
from pydantic import Field
from sailpoint.beta.models.provisioning_criteria_operation import ProvisioningCriteriaOperation
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class ProvisioningCriteriaLevel3(BaseModel):
    """
    Defines matching criteria for an Account to be provisioned with a specific Access Profile
    """ # noqa: E501
    operation: Optional[ProvisioningCriteriaOperation] = None
    attribute: Optional[StrictStr] = Field(default=None, description="Name of the Account attribute to be tested. If **operation** is one of EQUALS, NOT_EQUALS, CONTAINS, or HAS, this field is required. Otherwise, specifying it is an error.")
    value: Optional[StrictStr] = Field(default=None, description="String value to test the Account attribute w/r/t the specified operation. If the operation is one of EQUALS, NOT_EQUALS, or CONTAINS, this field is required. Otherwise, specifying it is an error. If the Attribute is not String-typed, it will be converted to the appropriate type.")
    children: Optional[StrictStr] = Field(default=None, description="Array of child criteria. Required if the operation is AND or OR, otherwise it must be left null. A maximum of three levels of criteria are supported, including leaf nodes.")
    __properties: ClassVar[List[str]] = ["operation", "attribute", "value", "children"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ProvisioningCriteriaLevel3 from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # set to None if attribute (nullable) is None
        # and model_fields_set contains the field
        if self.attribute is None and "attribute" in self.model_fields_set:
            _dict['attribute'] = None

        # set to None if children (nullable) is None
        # and model_fields_set contains the field
        if self.children is None and "children" in self.model_fields_set:
            _dict['children'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of ProvisioningCriteriaLevel3 from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "operation": obj.get("operation"),
            "attribute": obj.get("attribute"),
            "value": obj.get("value"),
            "children": obj.get("children")
        })
        return _obj





# coding: utf-8

"""
    IdentityNow Beta API

    Use these APIs to interact with the IdentityNow platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictBool, StrictStr, field_validator
from pydantic import Field
from sailpoint.beta.models.object_export_import_options import ObjectExportImportOptions
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class ImportOptions(BaseModel):
    """
    ImportOptions
    """ # noqa: E501
    exclude_types: Optional[List[StrictStr]] = Field(default=None, description="Object type names to be excluded from an sp-config export command.", alias="excludeTypes")
    include_types: Optional[List[StrictStr]] = Field(default=None, description="Object type names to be included in an sp-config export command. IncludeTypes takes precedence over excludeTypes.", alias="includeTypes")
    object_options: Optional[Dict[str, ObjectExportImportOptions]] = Field(default=None, description="Additional options targeting specific objects related to each item in the includeTypes field", alias="objectOptions")
    default_references: Optional[List[StrictStr]] = Field(default=None, description="List of object types that can be used to resolve references on import.", alias="defaultReferences")
    exclude_backup: Optional[StrictBool] = Field(default=False, description="By default, every import will first export all existing objects supported by sp-config as a backup before the import is attempted. If excludeBackup is true, the backup will not be performed.", alias="excludeBackup")
    __properties: ClassVar[List[str]] = ["excludeTypes", "includeTypes", "objectOptions", "defaultReferences", "excludeBackup"]

    @field_validator('exclude_types')
    def exclude_types_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in ('IDENTITY_OBJECT_CONFIG', 'IDENTITY_PROFILE', 'RULE', 'SOURCE', 'TRANSFORM', 'TRIGGER_SUBSCRIPTION'):
                raise ValueError("each list item must be one of ('IDENTITY_OBJECT_CONFIG', 'IDENTITY_PROFILE', 'RULE', 'SOURCE', 'TRANSFORM', 'TRIGGER_SUBSCRIPTION')")
        return value

    @field_validator('include_types')
    def include_types_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in ('IDENTITY_OBJECT_CONFIG', 'IDENTITY_PROFILE', 'RULE', 'SOURCE', 'TRANSFORM', 'TRIGGER_SUBSCRIPTION'):
                raise ValueError("each list item must be one of ('IDENTITY_OBJECT_CONFIG', 'IDENTITY_PROFILE', 'RULE', 'SOURCE', 'TRANSFORM', 'TRIGGER_SUBSCRIPTION')")
        return value

    @field_validator('default_references')
    def default_references_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in ('IDENTITY_OBJECT_CONFIG', 'IDENTITY_PROFILE', 'RULE', 'SOURCE', 'TRANSFORM', 'TRIGGER_SUBSCRIPTION'):
                raise ValueError("each list item must be one of ('IDENTITY_OBJECT_CONFIG', 'IDENTITY_PROFILE', 'RULE', 'SOURCE', 'TRANSFORM', 'TRIGGER_SUBSCRIPTION')")
        return value

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ImportOptions from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each value in object_options (dict)
        _field_dict = {}
        if self.object_options:
            for _key in self.object_options:
                if self.object_options[_key]:
                    _field_dict[_key] = self.object_options[_key].to_dict()
            _dict['objectOptions'] = _field_dict
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of ImportOptions from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "excludeTypes": obj.get("excludeTypes"),
            "includeTypes": obj.get("includeTypes"),
            "objectOptions": dict(
                (_k, ObjectExportImportOptions.from_dict(_v))
                for _k, _v in obj.get("objectOptions").items()
            )
            if obj.get("objectOptions") is not None
            else None,
            "defaultReferences": obj.get("defaultReferences"),
            "excludeBackup": obj.get("excludeBackup") if obj.get("excludeBackup") is not None else False
        })
        return _obj





# coding: utf-8

"""
    IdentityNow V3 API

    Use these APIs to interact with the IdentityNow platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from sailpoint.v3.models.document_type import DocumentType

class TestDocumentType(unittest.TestCase):
    """DocumentType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDocumentType(self):
        """Test DocumentType"""
        # inst = DocumentType()

if __name__ == '__main__':
    unittest.main()
